# 🚩 Installation

At the command line:

```shell
pip install redflag
```

Or, if you use Conda environments:

```shell
conda install -c conda-forge redflag
```

You can add the `conda-forge` channel as a source for future installations like so:

```shell
conda config --add channels conda-forge
conda config --set channel_priority strict
```


## Optional dependencies

For developers, there is an option to install `dev` dependencies: `pip install redflag[dev]` to install all testing and documentation packages.

If you want to help develop `redflag`, please read [Development](development.md).
